# ASR5515 Android 串口通信应用

## 项目概述
这是一个基于 Android 平台的串口通信应用，主要用于与 ASR5515 设备进行通信。该应用实现了完整的串口通信协议，支持设备管理、数据采集、状态监控等功能。

## 主要功能
1. 串口通信
   - 基于 Android SerialPort API 的串口通信实现
   - 支持自定义波特率和串口配置
   - 数据帧封装和解析

2. 设备管理
   - 设备检测和状态查询
   - 设备重启控制
   - 固件版本管理
   - 蓝牙模块管理

3. 数据采集
   - 心率、血压、血氧自动测量
   - 手动测量模式支持
   - 动态测量功能
   - 可配置的数据采集频率

4. 状态监控
   - 设备佩戴检测
   - 主机状态同步
   - 日志控制功能

## 技术架构

```mermaid
graph TD
    A[Android App] --> B[串口通信层]
    B --> C[协议解析层]
    C --> D[设备管理]
    C --> E[数据采集]
    C --> F[状态监控]
    
    B --> |SerialPortHelper| G[串口读写]
    C --> |ASR5515Protocol| H[协议实现]
    D --> |DeviceManager| I[设备控制]
```

## 核心模块

1. **SerialPortHelper**
   - 串口通信的核心类
   - 实现数据的发送和接收
   - 管理通信线程和数据队列

2. **ASR5515Protocol**
   - 实现 ASR5515 设备通信协议
   - 定义命令集和数据格式
   - 处理数据帧的封装和解析

3. **设备管理模块**
   - 设备信息查询
   - 设备控制命令
   - 固件升级支持

## 通信协议
- 帧格式：`[命令字(2字节) + 序列号(2字节) + 长度(2字节) + 数据 + ]`
- 支持的命令类型：
  - 设备检查 (0x0065/0x0066)
  - 设备重启 (0x0067/0x0068)
  - 状态同步 (0x0079/0x007A)
  - 数据采集 (0x00C9-0x00D0)
  - 佩戴检测 (0x0105/0x0106)

## 开发环境
- Android Studio
- Java
- Gradle 构建系统

## 依赖
- Android SerialPort API
- Android SDK

## 使用说明
1. 配置串口参数（波特率、设备路径）
2. 初始化 SerialPortHelper
3. 实现必要的回调接口
4. 使用设备管理和数据采集功能